@@ -92,9 +92,9 @@ def _run_ps(env, cluster):
     # Force parameter server to run on cpu. Running multiple TensorFlow processes on the same
     # GPU is not safe:
     # https://stackoverflow.com/questions/46145100/is-it-unsafe-to-run-multiple-tensorflow-processes-on-the-same-gpu
-    no_gpu_config = tf.ConfigProto(device_count={"GPU": 0})
+    no_gpu_config = tf.compat.v1.ConfigProto(device_count={"GPU": 0})
 
-    server = tf.train.Server(
+    server = tf.distribute.Server(
         cluster_spec, job_name="ps", task_index=task_index, config=no_gpu_config
     )
 
@@ -131,7 +131,7 @@ def train(env, cmd_args):
     """Get training job environment from env and run the training job.
 
     Args:
-        env (sagemaker_training.env.TrainingEnv): Instance of TrainingEnv class
+        env (sagemaker_training.environment.Environment): Instance of Environment class
     """
     parameter_server_enabled = env.additional_framework_parameters.get(
         SAGEMAKER_PARAMETER_SERVER_ENABLED, False
@@ -204,7 +204,7 @@ def _log_model_missing_warning(model_dir):
 
 
 def _model_dir_with_training_job(model_dir, job_name):
-    if model_dir and model_dir.startswith("/opt/ml"):
+    if model_dir.startswith("/opt/ml"):
         return model_dir
     else:
         return "{}/{}/model".format(model_dir, job_name)
